@@ -1,7 +1,11 @@
-#!/usr/bin/perl -W -T
+#!/usr/bin/perl -W
 use strict;
 use lib '.'; # allows the .pl files to be read via require()
 
+unless (-d 'eponymous_directory') {
+	print STDERR "Script can only be run from the examples directory or wherever the 'eponymous_directory' is.\n";
+}
+
 package eponymous_directory;
 # eponymous means the same name ... as the package 'eponymous_directory'
 
@@ -9,12 +13,11 @@ use Package::Transporter sub{eval shift}, sub {
 	$_[0]->register_potential('::Eponymous_Directory', 'FOR_SELF', undef);
 };
 
-yn(potentially_defined('hello_worlds'));
+yn(!potentially_defined('hello_worlds'));
 yn(potentially_defined('hello_world'));
-yn(defined(&hello_world));
+yn(!defined(&hello_world));
 
 hello_world();
 
 yn(defined(&hello_world));
-
-exit(0);
\ No newline at end of file
+exit(0);
