@@ -38,19 +38,19 @@ sub implement {
 	my $suggested = $self->[ATB_SUGGESTSIONS]->lookup($sub_name, $ref, scalar(@_));
 
 	unless (defined($suggested)) {
-		return(Package::Transporter::Generator::failure(undef, $sub_name, '::Suggested_Use [no suggestion found]'));
+		return($self->failure(undef, $sub_name, '::Suggested_Use [no suggestion found]'));
 	}
 	my ($load, $module) = @$suggested;
 	
 	my $sub_text;
 	if ($load eq 'use') {
 		$sub_text = sprintf(q{
-my $verbose = shift(@_);
+my ($self, $verbose) = (shift(@_), shift(@_));
 print STDERR qq{Loading suggested module '%s' to enable subroutine '%s'.\n} if ($verbose);
 use %s;
 return(\&%s) if (defined(&%s));
 return(\&%s::%s) if (defined(&%s::%s));
-return(Package::Transporter::Generator::failure(undef, '%s', q{::Suggested_Use ['use %s' had not the required effect]}));
+return($self->failure(undef, '%s', q{::Suggested_Use ['use %s' had not the required effect]}));
 		},
 			$module, $sub_name,
 			$module,
@@ -59,22 +59,22 @@ return(Package::Transporter::Generator::failure(undef, '%s', q{::Suggested_Use [
 			$sub_name, $module);
 	} elsif ($load eq 'parent') {
 		$sub_text = sprintf(q{
-my $verbose = shift(@_);
+my ($self, $verbose) = (shift(@_), shift(@_));
 print STDERR qq{Loading suggested parent '%s' to enable method '%s'.\n} if ($verbose);
 use parent qw(%s);
 my $can = UNIVERSAL::can($_[0], '%s');
 return($can) if (defined($can));
-return(Package::Transporter::Generator::failure(undef, '%s', q{::Suggested_Use ['use parent qw(%s)' had not the required effect]}));
+return($self->failure(undef, '%s', q{::Suggested_Use ['use parent qw(%s)' had not the required effect]}));
 		},
 			$module, $sub_name,
 			$module,
 			$sub_name,
 			$sub_name, $module);
 	} else {
-		return(Package::Transporter::Generator::failure(undef, $sub_name, "::Suggested_Use [invalid loading '$load']"));
+		return($self->failure(undef, $sub_name, "::Suggested_Use [invalid loading '$load']"));
 	}
 
-	return($pkg->transport(\$sub_text, $VERBOSE, $_[0]));
+	return($pkg->transport(\$sub_text, $self, $VERBOSE, $_[0]));
 }
 
-1;
\ No newline at end of file
+1;
